<?php

/**
 * hostby functions and definitions
  @package Hostby
 *
*/

/* Set the content width in pixels, based on the theme's design and stylesheet.
*/
if( ! function_exists( 'hostby_theme_setup' ) ) {

	function hostby_theme_setup() {

		$GLOBALS['content_width'] = apply_filters( 'hostby_content_width', 980 );

		load_theme_textdomain( 'hostby', get_template_directory() . '/languages' );

        // Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

        // Add title tag 
		add_theme_support( 'title-tag' );

		// Add default logo support		
        add_theme_support( 'custom-logo');

        add_theme_support('post-thumbnails');
        add_image_size('hostby-services-thumbnail',60,60,true);
        add_image_size('hostby-page-thumbnail',738,423, true);
        add_image_size('hostby-about-thumbnail',370,225, true);
        add_image_size('hostby-blog-front-thumbnail',370,225, true);
        add_image_size('hostby-projects-thumbnail',500,400, true);
        
        // Add theme support for Semantic Markup
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) ); 

		$defaults = array(
			'default-image'          => get_template_directory_uri() .'/assets/images/blog-banner.jpg',
			'width'                  => 1920,
			'height'                 => 540,
			'uploads'                => true,
			'default-text-color'     => "#000",
			'wp-head-callback'       => 'hostby_header_style',
			
			);
		add_theme_support( 'custom-header', $defaults );

		// Menus
		register_nav_menus(
			array(
                'primary' => esc_html__('Primary Menu', 'hostby'),
            )
		);
		// add excerpt support for pages
        add_post_type_support( 'page', 'excerpt' );

        if ( is_singular() && comments_open() ) {
			wp_enqueue_script( 'comment-reply' );
        }
		// Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );
		
    	// To use additional css
 	    add_editor_style( 'assets/css/editor-style.css' );
		
		// Custom Backgrounds
   		add_theme_support( 'custom-background', array(
  			'default-color' => 'ffffff',
    	) );
		//About Theme		
		if ( is_admin() ) {
			require( get_template_directory() . '/include/welcome-screen.php');
		}	

	}
	add_action( 'after_setup_theme', 'hostby_theme_setup' );
}

// Register Nav Walker class_alias
   require_once('class-wp-bootstrap-navwalker.php');
   
/**
 * Load Upsell Button In Customizer
 * 2016 &copy; [Justin Tadlock](http://justintadlock.com).
 */

require_once( trailingslashit( get_template_directory() ) . '/include/upgrade/class-customize.php' ); 
   
/**
 * Enqueue CSS stylesheets
 */		
if( ! function_exists( 'hostby_enqueue_styles' ) ) {
	function hostby_enqueue_styles() {	
	    
	    wp_enqueue_style('hostby-font', 'https://fonts.googleapis.com/css?family=Nunito:300,400,600,700,800');
		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css');
		wp_enqueue_style('font-awesome', get_template_directory_uri() .'/assets/css/font-awesome.css');
		wp_enqueue_style('carousel', get_template_directory_uri() .'/assets/css/owl.carousel.css');
		wp_enqueue_style('hostby-theme', get_template_directory_uri() .'/assets/css/owl.theme.default.css');
		wp_enqueue_style('animate', get_template_directory_uri() .'/assets/css/animate.css');
		wp_enqueue_style('menubar', get_template_directory_uri() . '/assets/css/menubar.css');	
		// main style
		wp_enqueue_style( 'hostby-style', get_stylesheet_uri() );
		wp_enqueue_style('hostby-blue', get_template_directory_uri() . '/assets/css/skin-blue.css');
		 
		wp_enqueue_style('responsive', get_template_directory_uri() .'/assets/css/responsive.css');
	}
	add_action( 'wp_enqueue_scripts', 'hostby_enqueue_styles');
}
/**
 * Enqueue JS scripts
*/

if( ! function_exists( 'hostby_enqueue_scripts' ) ) {
	function hostby_enqueue_scripts() {   
		wp_enqueue_script('jquery');
		wp_enqueue_script('popper', get_template_directory_uri() . '/assets/js/popper.js',array(),'', true);
		wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js',array(),'', true);
		wp_enqueue_script('carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js',array(),'', true);
		wp_enqueue_script('imagesloaded', get_template_directory_uri() . '/assets/js/imagesloaded.js',array(),'', true);
		wp_enqueue_script('isotope', get_template_directory_uri() . '/assets/js/isotope.js',array(),'', true);
		wp_enqueue_script('poptrox', get_template_directory_uri() . '/assets/js/jquery.poptrox.js',array(),'', true);
		wp_enqueue_script('hostby-custom', get_template_directory_uri() . '/assets/js/custom.js',array(),'', true);
	}
	add_action( 'wp_enqueue_scripts', 'hostby_enqueue_scripts' );
}

/**
 * Register sidebars for hostby
*/
function hostby_sidebars() {

	// Blog Sidebar
	
	register_sidebar(array(
		'name' => esc_html__( 'Blog Sidebar', "hostby"),
		'id' => 'blog-sidebar',
		'description' => esc_html__( 'Sidebar on the blog layout.', "hostby"),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="border-arrow">',
		'after_title' => '</h3>',
	));
  	

	// Footer Sidebar
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 1', "hostby"),
		'id' => 'hostby-footer-widget-area-1',
		'description' => esc_html__( 'The footer widget area 1', "hostby"),
		'before_widget' => '<div class="widget %2$s"> ',
		'after_widget' => '</div> ',
		'before_title' => '<h4 class="foot-heading">',
		'after_title' => '</h4>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 2', "hostby"),
		'id' => 'hostby-footer-widget-area-2',
		'description' => esc_html__( 'The footer widget area 2', "hostby"),
		'before_widget' => '<div class="widget %2$s">  ',
		'after_widget' => ' </div>',
		'before_title' => '<h4 class="foot-heading">',
		'after_title' => '</h4>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 3', "hostby"),
		'id' => 'hostby-footer-widget-area-3',
		'description' => esc_html__( 'The footer widget area 3', "hostby"),
		'before_widget' => '<div class="widget %2$s"> ',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="foot-heading">',
		'after_title' => '</h4>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 4', "hostby"),
		'id' => 'hostby-footer-widget-area-4',
		'description' => esc_html__( 'The footer widget area 4', "hostby"),
		'before_widget' => '<div class="widget %2$s"> ',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="foot-heading">',
		'after_title' => '</h4>',
	));		
}

add_action( 'widgets_init', 'hostby_sidebars' );

function hostby_header_style()
{
	$header_text_color = get_header_textcolor();
	?>
		<style type="text/css">
			<?php
				//Check if user has defined any header image.
				if ( get_header_image() ) :
			?>
				.site-title{
					color: #<?php echo esc_attr($header_text_color); ?>;
					
				}
			<?php endif; ?>	
		</style>
	<?php

}

/**
 * Load Upsell Button In Customizer
 * 2016 &copy; [Justin Tadlock](http://justintadlock.com).
 */

//require_once( trailingslashit( get_template_directory() ) . '/include/upgrade/class-customize.php' );

add_action( 'admin_init', 'hostby_detect_button' );
	function hostby_detect_button() {
	wp_enqueue_style( 'hostby-info-button', get_template_directory_uri() . '/assets/css/import-button.css' );
}

/**
 * admin  JS scripts
 */
function dignify_admin_enqueue_scripts( $hook ) { 
	wp_enqueue_style( 
		'font-awesome', 
		get_template_directory_uri() . '/assets/css/font-awesome.css', 
		array(), 
		'4.7.0', 
		'all' 
	);
	wp_enqueue_style( 
		'erzen-admin', 
		get_template_directory_uri() . '/assets/admin/css/admin.css', 
		array(), 
		'1.0.0', 
		'all' 
	);
 
}
add_action( 'admin_enqueue_scripts', 'dignify_admin_enqueue_scripts' );

 /**
 * Comment layout
 */
function hostby_comments( $comment, $args, $depth ) { 
    $GLOBALS['comment'] = $comment; ?>
	<div <?php comment_class('comments'); ?> id="<?php comment_ID() ?>">
	    <?php if ($comment->comment_approved == '0') : ?>
	        <div class="alert alert-info">
	          <p><?php esc_html_e( 'Your comment is awaiting under moderation.', 'hostby' ) ?></p>
	        </div>
	    <?php endif; ?>
	    <div class="comment-inner">
            <a class="reply"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></a>
	        <div class="com-img">
	           <a href="#"><?php echo get_avatar( $comment,'88', null,'User', array( 'class' => array( 'media-object','' ) )); ?></a>
	        </div>
	        <div class="com-content">
	            <h4>
	                <?php 
	                        /* translators: '%1$s %2$s: edit term */
	                printf(esc_html__( '%1$s %2$s', 'hostby' ), get_comment_author_link(), edit_comment_link(esc_html__( '(Edit)', 'hostby' ),'  ','') ) ?> </h4>
	                <h5 class="fw-600"><time datetime="<?php echo comment_time('c'); ?>">
						<?php printf(  /* translators: 1: date, 2: time */
							_x( '%1$s at %2$s', '1: date, 2: time', 'hostby' ),
								get_comment_date(),
								get_comment_time()
							); ?></time>
					</h5>
	            <?php comment_text() ;?>
	        </div>
        </div>
	</div>
<?php
} 


/**
 * Customizer Settings
*/
require get_template_directory(). '/customizer.php';

if ( ! function_exists( 'hostby_customize_search_form' ) ) :
	function hostby_customize_search_form() {
        
        $form = '<div class="widget search-widget"><form role="search" method="get" class=" input-group" action="' . esc_url( home_url( '/' ) ) . '">
			
			<span class="screen-reader-text">' . esc_html( '', 'label', 'hostby' ) . '</span>
			<input type="search" class="form-group form-control" placeholder="' . esc_attr_x( 'Search', 'placeholder', 'hostby' ) . '" value="' . get_search_query() . '" name="s" title="' . esc_attr_x( 'Search for:', 'label', 'hostby' ) . '" />
			
			<button type="submit" class="btn btn-widget">
                <i class="fa fa-search"></i>
            </button>
            </form></div>';
        return $form;
    }
endif;
add_filter( 'get_search_form', 'hostby_customize_search_form', 15 );


$hostby_view_demo = esc_html( __( 'View Demo', 'hostby'));
$hostby_upgrade_to_pro = esc_html( __( 'Upgrade To Pro', 'hostby' ));

 
function hostby_theme_page() {
	$title = esc_html(__('hostby Theme','hostby'));
	add_theme_page( 
		esc_html(__( 'Upgrade To hostby Pro','hostby')),
		$title.'', 
		'edit_theme_options',
		'hostby_upgrade',
		'hostby_display_upgrade'
	);
}

add_action('admin_menu','hostby_theme_page');


function hostby_display_upgrade() {
  $theme_data = wp_get_theme('hostby'); 
    
    // Check for current viewing tab
    $tab = null;
    if ( isset( $_GET['tab'] ) ) {
        $tab = $_GET['tab'];
    } else {
        $tab = null;
    } 
     
    $pro_theme_url = 'http://gurutemplate.com/themes/hostby-pro/';
    $pro_theme_demo = 'http://gurutemplate.com/themes/demo-hostby-pro/';
    $doc_url  = 'http://gurutemplate.com/docs/hostby-doc/index.html';
    $support_url = 'https://wordpress.org/support/theme/hostby';   
    $rating_url = 'https://wordpress.org/support/theme/hostby/reviews/?filter=5';   
    
    $current_action_link =  admin_url( 'themes.php?page=hostby_upgrade&tab=pro_features' ); ?>
    <style>
	.about-wrap .about-text {
		margin: 0em 0px 0em 0  !important;;
		margin-bottom: 25px !important;
		min-height: 60px;
		color: #555d66;
	}
	.about-wrap {		
		max-width: 1200px;	
	}
	</style>
	<div class="construction-zone-wrapper about-wrap">
        <h1><?php printf(esc_html__('Welcome to %1$s - Version %2$s', 'hostby'), $theme_data->Name ,$theme_data->Version ); ?></h1><?php
       	printf( __('<div class="about-text"> hostby is a free hosting wordpress Theme has responsive design made with bootstrap, retina ready blog layout enable and with sidebar. hostby comes with full screen slider, high quality Home Page including gallery or portfolio section, testimonial section, service section, team section, recent post section & client logo section. hostby fully customizable built on wordpress customizer that enable you to configure your website in live preview. Theme is SEO friendly, Cross browser compatible And compatible with all major plugins.', 'hostby') ); ?>
       <p class="upgrade-btn"><a class="upgrade btn1" href="<?php echo esc_url($pro_theme_demo); ?>" target="_blank"><?php printf( __( 'View Premium Demo', 'hostby'), $theme_data->Name ); ?></a></p>
	   <p class="upgrade-btn"><a class="upgrade" href="<?php echo esc_url($pro_theme_url); ?>" target="_blank"><?php printf( __( 'Upgrade To %1s Pro - $55', 'hostby'), $theme_data->Name ); ?></a></p>

	   <h2 class="nav-tab-wrapper">
	        <a href="?page=hostby_upgrade" class="nav-tab<?php echo is_null($tab) ? ' nav-tab-active' : null; ?>"><?php echo $theme_data->Name; ?></a>
<a href="?page=hostby_upgrade&tab=pro_features" class="nav-tab<?php echo $tab == 'pro_features' ? ' nav-tab-active' : null; ?>"><?php esc_html_e( 'PRO Features', 'hostby' );  ?></a>
            <a href="?page=hostby_upgrade&tab=free_vs_pro" class="nav-tab<?php echo $tab == 'free_vs_pro' ? ' nav-tab-active' : null; ?>"><?php esc_html_e( 'Free VS PRO', 'hostby' ); ?></a>
	        <?php do_action( 'hostby_admin_more_tabs' ); ?>
	    </h2>      

        <?php if ( is_null( $tab ) ) { ?>
            <div class="theme_info info-tab-content">
                <div class="theme_info_column clearfix">
                    <div class="theme_info_left">
                        <div class="theme_link">
                            <h3><?php esc_html_e( 'Theme Customizer', 'hostby' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('%s supports the Theme Customizer for all theme settings. Click "Customize" to start customize your site.', 'hostby'), $theme_data->Name); ?></p>
                            <p>
                                <a href="<?php echo admin_url('customize.php'); ?>" class="button button-primary"><?php esc_html_e('Start Customize', 'hostby'); ?></a>
                            </p>
                        </div>
                        <div class="theme_link">
                            <h3><?php esc_html_e( 'Theme Documentation', 'hostby' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('Need any help to setup and configure %s? Please have a look at our documentations instructions.', 'hostby'), $theme_data->Name); ?></p>
                            <p>
                                <a href="<?php echo esc_url($doc_url); ?>" target="_blank" class="button button-primary"><?php esc_html_e(' Documentation', 'hostby'); ?></a>
                            </p>
                            <?php do_action( 'hostby_dashboard_theme_links' ); ?>
                        </div>  
                        <div class="theme_link">
                            <h3><?php esc_html_e( 'Having Trouble, Need Support?', 'hostby' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('Support for %s WordPress theme is conducted through Genex free support ticket system.', 'hostby'), $theme_data->Name); ?></p>
                            <p>  
                                <a href="<?php echo esc_url($support_url); ?>" target="_blank" class="button button-primary"><?php echo sprintf( esc_html('Create a support ticket', 'hostby'), $theme_data->Name); ?></a>
                            </p>
                        </div> 
						 <div class="theme_link">
                            <h3><?php esc_html_e( 'Please Rate Us', 'hostby' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('We need your help to expand or and portoflio so please rate us on wordpress ', 'hostby'), $theme_data->Name); ?></p>
                            <p>  
                                <a href="<?php echo esc_url($rating_url); ?>" target="_blank" class="button button-primary"><?php echo sprintf( esc_html('Rate This Theme', 'hostby'), $theme_data->Name); ?></a>
                            </p>
                        </div> 
						 <div class="theme_link">
                            <h3><?php esc_html_e( 'View Pro Features', 'hostby' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('You can check premum features of theme here', 'hostby'), $theme_data->Name); ?></p>
                            <p>  
                                <a href="<?php echo esc_url($pro_theme_url); ?>" target="_blank" class="button button-primary"><?php echo sprintf( esc_html('View Pro Features', 'hostby'), $theme_data->Name); ?></a>
                            </p>
                        </div> 
                       
                    </div>  
                    <div class="theme_info_right">
                        <?php echo sprintf ( '<img src="'. get_template_directory_uri() .'/screenshot.jpg" alt="%1$s" />',__('Theme screenshot','hostby') ); ?>
                    </div>
                </div> 
            </div>
        <?php } ?>
	
        <?php if ( $tab == 'pro_features' ) { ?>
            <div class="pro-features-tab info-tab-content">
			 
				<div class="wrap clearfix">
				   <div class="one-third column clear">
	<div class="icon-wrap"><i class="fa  fa-5x fa-cog"></i></div>
	<h3><?php echo esc_html(__( '2 Home Pages', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__('Theme supports 3 types of Home Pages with different UI elements styles - slider, projects, services, features, team', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-th-large"></i></div>
	<h3><?php echo esc_html(__( '2 Header Preset', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__('Theme offers 4 tytpes of header navgiation preset so you can change and select your header design', 'hostby' )); ?></p>
</div>

<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-th-large"></i></div>
	<h3><?php echo esc_html(__( 'One Click Demo Import', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__('You can import demo data as shown on the demo as it is', 'hostby' )); ?></p>
</div>

<div class="one-third column clear">
	<div class="icon-wrap"><i class="fa  fa-5x fa-paint-brush"></i></div>
	<h3><?php echo esc_html(__( 'Unlimited Color Scheme', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'Theme support Unlimited Color Option that mean you can design your website with any color.', 'hostby' )); ?></p>
</div>

<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-pencil"></i></div>
	<h3><?php echo esc_html(__( 'Blog', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'Theme support List View and Vintage look of blog. This will give perfect look to your blog ', 'hostby' )); ?></p>
</div>

<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-question-circle"></i></div>
	<h3><?php echo esc_html(__( 'FAQ Page', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'Theme support List View and Vintage look of blog. This will give perfect look to your blog ', 'hostby' )); ?></p>
</div>

<div class="one-third column clear">
	<div class="icon-wrap"><i class="fa  fa-5x fa-gavel"></i></div>
	<h3><?php echo esc_html(__( '5+ Services', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'Theme support 5+ Serve design. So you can display services and designs in various look', 'hostby' )); ?></p>
</div>

<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-user"></i></div>
	<h3><?php echo esc_html(__( '2 Team Style', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'Theme support 2 Team style so you can display two types of team', 'hostby' )); ?></p>
</div>

<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-globe"></i></div>
	<h3><?php echo esc_html(__( '404 Page', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( '404 Page is designed ultimately and it is very attractive', 'hostby' )); ?></p>
</div>

<div class="one-third column clear">
	<div class="icon-wrap"><i class="fa  fa-5x fa-envelope"></i></div>
	<h3><?php echo esc_html(__( 'Contact Form 7', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'hostby Pro support contact form 7 that mean you can easily add your contact form with theme design ', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-th"></i></div>
	<h3><?php echo esc_html(__( 'Portfolio', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'Theme support Grid and Masonary Portfolio layout for the users. You can select either grid or portfolio design ', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-font"></i></div>
	<h3><?php echo esc_html(__( 'Typography', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__('Theme loves typography, you can choose from over 500+ Google Fonts and Standard Fonts to customize your site!', 'hostby' )); ?></p>
</div>
<div class="one-third column clear">
	<div class="icon-wrap"><i class="fa  fa-5x fa-slideshare"></i></div>
	<h3><?php echo esc_html(__( 'Unlimitd Image Slides', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__('Theme includes Flex slider . You can add unlimited slides on your home page', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-user"></i></div>
	<h3><?php echo esc_html(__( 'Contact Page', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__('You can add contact page to your theme easily so customer can contact yuo directly. ', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-magic"></i></div>
	<h3><?php echo esc_html(__( 'Retina Ready', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'Theme is Retina Ready. So, Everything looks amazingly sharp and crisp on high resolution retina displays of all sizes!', 'hostby' )); ?></p>
</div>
<div class="one-third column clear">
	<div class="icon-wrap"><i class="fa  fa-5x fa-dashboard"></i></div>
	<h3><?php echo esc_html(__( 'Awesome Icons', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( ' Choose from over 2500+ icons are fully integrated into the theme ', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-magic"></i></div>
	<h3><?php echo esc_html(__( 'Excellent Support', 'hostby' )); ?></h3>
	<p><?php echo esc_html(__( 'We truly care about our customers and themes performance. We assure you that you will get the best after sale support like never before!', 'hostby' ));
 ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-desktop"></i></div>
	<h3><?php echo esc_html(__( 'Responsive Layout', 'hostby' )); ?></h3>
	<p><?php echo esc_html( __('Theme is fully responsive and can adapt to any screen size. Resize your browser window to view it!', 'hostby' )); ?></p>
</div>
<div class="one-third column clear">
	<div class="icon-wrap"><i class="fa  fa-5x fa-rocket"></i></div>
	<h3><?php echo esc_html( __( 'Testimonials', 'hostby' ));?></h3>
	<p><?php echo  esc_html( __( 'Display your clients\' glowing comments about your business on your homepage. Showing a specific number of testimonials with use of testimonial widget. ', 'hostby' ));?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-skype"></i></div>
	<h3><?php echo esc_html( __( 'Social Media', 'hostby' )); ?></h3>
	<p><?php echo esc_html( __( 'Want your users to stay in touch? No problem, Theme has Social Media icons all throughout the theme!', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-map-marker"></i></div>
	<h3><?php echo esc_html( __( 'Add Timeline', 'hostby' )); ?></h3>
	<p><?php echo esc_html( __('This Theme includes Timeline shortcode, So you can easily display your company history to your visitors or  your clients', 'hostby' )); ?></p>
</div>
<div class="one-third column clear">
	<div class="icon-wrap"><i class="fa  fa-5x fa-edit"></i></div>
	<h3><?php echo esc_html( __( 'Customization', 'hostby' )); ?></h3>
	<p><?php echo esc_html( __('With advanced theme options, page options & extensive docs, its never been easier to customize a theme!', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-check"></i></div>
	<h3><?php echo esc_html( __( 'Demo content', 'hostby' )); ?></h3>
	<p><?php echo esc_html( __('Theme includes single click demo content. You can quickly setup the site like our demo and get started easily!', 'hostby' )); ?></p>
</div>
<div class="one-third column">
	<div class="icon-wrap"><i class="fa  fa-5x fa-signal"></i></div>
	<h3><?php echo esc_html( __( 'Improvement', 'hostby' )); ?></h3>
	<p><?php echo esc_html( __('We love our theme and customers. We are committed to improve and add new features to Theme!', 'hostby' )); ?></p>
</div>


				</div>
			</div><?php   
		} ?>  

       <!-- Free VS PRO tab -->
        <?php if ( $tab == 'free_vs_pro' ) { ?>
            <div class="free-vs-pro-tab info-tab-content">
	            <div id="free_pro">
	                <table class="free-pro-table">
		                <thead>
			                <tr>
			                    <th></th>  
			                    <th><?php echo esc_html($theme_data->Name); ?> Lite</th>
			                    <th><?php echo esc_html($theme_data->Name); ?> PRO</th>
			                </tr>
		                </thead>
		                <tbody>
		                    <tr>
		                        <td><h3><?php _e('Responsive Design', 'hostby'); ?></h3></td>
		                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                    <tr>
		                        <td><h3><?php _e('Support', 'hostby'); ?></h3></td>
		                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>		                    
		                    <tr>
		                        <td><h3><?php _e('Custom Logo Option', 'hostby'); ?></h3></td>
		                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                    <tr>
		                         <td><h3><?php _e('Social Links', 'hostby'); ?></h3></td>
		                         <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                         <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                    <tr>
		                    	 <td><h3><?php _e('Unlimited color option', 'hostby'); ?></h3></td>
		                    	 <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	 <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                    <tr>
		                    	 <td><h3><?php _e('3 Home page', 'hostby'); ?></h3></td>
		                    	 <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	 <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
							 <tr>
		                    	 <td><h3><?php _e('Header Presets', 'hostby'); ?></h3></td>
		                    	 <td class="only-pro"><?php _e('1', 'hostby'); ?></td>
		                    	 <td class="only-lite"><?php _e('3', 'hostby'); ?></td>
		                    </tr>	
		                     <tr>
		                    	 <td><h3><?php _e('Pre Defined Page Templates', 'hostby');?></h3></td>
		                    	 <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	 <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                    <tr>
		                    	<td><h3><?php _e('4 Portfolio Presets', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                    <tr>
		                    	<td><h3><?php _e('Team With Detail Page', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                    <tr>
		                    	<td><h3><?php _e('Redux Theme Option Panel', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr> 
							 
							<tr>
		                    	<td><h3><?php _e('Sticky Header Option', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
							<tr>
		                    	<td><h3><?php _e('Contact Form 7', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
							<tr>
		                    	<td><h3><?php _e('15+ Shortcodes', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
							<tr>
		                    	<td><h3><?php _e('Google Fonts', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
							 
		                     <tr>
		                    	<td><h3><?php _e('Multiple Service Layouts', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
							 <tr>
		                    	<td><h3><?php _e('Team Page', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                     <tr>
		                    	<td><h3><?php _e('Multiple Blog Layouts', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                     <tr>
		                    	<td><h3><?php _e('Page Animation', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                     <tr>
		                    	<td><h3><?php _e('Premium Priority Support', 'hostby');?></h3></td>
		                    	<td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
		                    	<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
		                    </tr>
		                    
		                    <tr class="ti-about-page-text-center">
		                        <td><a href="<?php echo esc_url($pro_theme_demo); ?>" target="_blank" class="button button-primary button-hero"><?php printf( __( '%1s Pro Demo', 'hostby'), $theme_data->Name ); ?></a></td>
		                    	<td colspan="2"><a href="<?php echo esc_url($pro_theme_url); ?>" target="_blank" class="button button-primary button-hero"><?php printf( __( 'Upgrade To %1s Pro', 'hostby'), $theme_data->Name ); ?></a></td>
		                    </tr>
		                </tbody>
	                </table>			    
				</div>
			</div><?php 
		} ?>

    </div><?php
} ?>


