<?php
/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Hostby_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		get_template_part('include/upgrade/section-pro');
		
		// Register custom section types.
		$manager->register_section_type( 'Hostby_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Hostby_Customize_Section_Pro(
				$manager,
				'hostby',
				array(
					'title'    => esc_html__( 'Theme Documentation', 'hostby' ),
					'pro_text' => esc_html__( 'Click Here', 'hostby' ),
					'pro_url'  => 'http://gurutemplate.com/docs/hostby-doc/index.html',
					'priority'  => 1
				)
			)
		);
		
		// Register sections.
		$manager->add_section(
			new Hostby_Customize_Section_Pro(
				$manager,
				'upgrade-pro',
				array(
					'title'    => esc_html__( 'Upgrade To Pro', 'hostby' ),
					'pro_text' => esc_html__( 'View Pro', 'hostby' ),
					'pro_url'  => 'http://gurutemplate.com/themes/hostby-pro/',
					'priority'  => 1
				)
			)
		);
		// Register sections.
		$manager->add_section(
			new Hostby_Customize_Section_Pro(
				$manager,
				'upgrade-pros',
				array(
					'title'    => esc_html__( 'Check Pro Features', 'hostby' ),
					'pro_text' => esc_html__( 'Pro Features', 'hostby' ),
					'pro_url'  => 'http://gurutemplate.com/themes/hostby-pro/',
					'priority'  => 250
				)
			)
		);
		 
	}


	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'hostby-customize-controls', trailingslashit( get_template_directory_uri() ) . '/include/upgrade/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'hostby-customize-controls', trailingslashit( get_template_directory_uri() ) . '/include/upgrade/customize-controls.css' );
	}
}

// Doing this customizer thang!
Hostby_Customize::get_instance();
